@@ -1,4 +1,4 @@
-from pycabanas.global_routines import *
+from global_routines import *
 import numpy as np
 import matplotlib.pyplot as plt
 from collections import Counter
